==> boost_1_80_0.tar.bz2: boost_1_80_0/libs/locale/doc/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Boost.Locale", "index.html", [
    [ "What is Boost.Locale?", "index.html#main_intro", null ],
    [ "Tutorials", "index.html#main_tutorial", null ],
    [ "Introduction to C++ Standard Library localization support", "std_locales.html", [
      [ "Getting familiar with standard C++ Locales", "std_locales.html#std_locales_basics", null ],
      [ "Common Critical Problems with the Standard Library", "std_locales.html#std_locales_common", null ]
    ] ],
    [ "Using Boost.Locale", "using_boost_locale.html", "using_boost_locale" ],
    [ "Using Localization Backends", "using_localization_backends.html", [
      [ "When to use non-ICU backends", "using_localization_backends.html#when_to_use_non_icu_backends", null ],
      [ "Non-ICU Backends", "using_localization_backends.html#non_icu_backends", [
        [ "std - The standard C++ library backend", "using_localization_backends.html#std_backend", null ],
        [ "posix - POSIX 2008 C library", "using_localization_backends.html#posix_backend", null ],
        [ "winapi - Win32 API.", "using_localization_backends.html#winapi_backend", null ]
      ] ],
      [ "Supported Features", "using_localization_backends.html#supported_features_by_backends", null ],
      [ "Using Localization Backends", "using_localization_backends.html#using_localization_backends", null ]
    ] ],
    [ "Recommendations and Myths", "recommendations_and_myths.html", [
      [ "Recommendations", "recommendations_and_myths.html#recommendations", null ],
      [ "Myths", "recommendations_and_myths.html#myths", [
        [ "To use Unicode in my application I should use wide strings everywhere.", "recommendations_and_myths.html#myths_wide", null ],
        [ "UTF-16 is the best encoding to work with.", "recommendations_and_myths.html#myths_utf16", null ]
      ] ]
    ] ],
    [ "Building The library", "building_boost_locale.html", [
      [ "Building Boost.Locale", "building_boost_locale.html#building_boost_locale_bb", [
        [ "Dependencies", "building_boost_locale.html#bb_building_deps", null ],
        [ "Platform Notes", "building_boost_locale.html#bb_platform_opts", null ],
        [ "Building Process", "building_boost_locale.html#bb_building_proc", null ]
      ] ],
      [ "Build Options", "building_boost_locale.html#bb_build_opts", null ],
      [ "Running Unit Tests", "building_boost_locale.html#bb_build_test", null ],
      [ "Binary Compatibility", "building_boost_locale.html#binary_compatibility", null ]
    ] ],
    [ "Appendix", "appendix.html", "appendix" ],
    [ "Changelog", "changelog.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"classboost_1_1locale_1_1generator.html#a767403ea3f6259fd184a6e355caf62f2",
"group__boundary.html#ga1f813e25280a6165cc270ced46bc8c58",
"group__message.html#ga529423e08fc9a8ca9ceef5c56181c6d3"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> boost_1_81_0.tar.bz2: boost_1_81_0/libs/locale/doc/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Boost.Locale", "index.html", [
    [ "What is Boost.Locale?", "index.html#main_intro", null ],
    [ "Tutorials", "index.html#main_tutorial", null ],
    [ "Introduction to C++ Standard Library localization support", "std_locales.html", [
      [ "Getting familiar with standard C++ Locales", "std_locales.html#std_locales_basics", null ],
      [ "Common Critical Problems with the Standard Library", "std_locales.html#std_locales_common", null ]
    ] ],
    [ "Using Boost.Locale", "using_boost_locale.html", "using_boost_locale" ],
    [ "Using Localization Backends", "using_localization_backends.html", [
      [ "When to use non-ICU backends", "using_localization_backends.html#when_to_use_non_icu_backends", null ],
      [ "Non-ICU Backends", "using_localization_backends.html#non_icu_backends", [
        [ "std - The standard C++ library backend", "using_localization_backends.html#std_backend", null ],
        [ "posix - POSIX 2008 C library", "using_localization_backends.html#posix_backend", null ],
        [ "winapi - Win32 API.", "using_localization_backends.html#winapi_backend", null ]
      ] ],
      [ "Supported Features", "using_localization_backends.html#supported_features_by_backends", null ],
      [ "Using Localization Backends", "using_localization_backends.html#using_localization_backends_sec", null ]
    ] ],
    [ "Recommendations and Myths", "recommendations_and_myths.html", [
      [ "Recommendations", "recommendations_and_myths.html#recommendations", null ],
      [ "Myths", "recommendations_and_myths.html#myths", [
        [ "To use Unicode in my application I should use wide strings everywhere.", "recommendations_and_myths.html#myths_wide", null ],
        [ "UTF-16 is the best encoding to work with.", "recommendations_and_myths.html#myths_utf16", null ]
      ] ]
    ] ],
    [ "Building the Library", "building_boost_locale.html", [
      [ "Building Boost.Locale", "building_boost_locale.html#building_boost_locale_bb", [
        [ "Dependencies", "building_boost_locale.html#bb_building_deps", null ],
        [ "Platform Notes", "building_boost_locale.html#bb_platform_opts", null ],
        [ "Building Process", "building_boost_locale.html#bb_building_proc", null ]
      ] ],
      [ "Build Options", "building_boost_locale.html#bb_build_opts", null ],
      [ "Running Unit Tests", "building_boost_locale.html#bb_build_test", null ],
      [ "Binary Compatibility", "building_boost_locale.html#binary_compatibility", null ]
    ] ],
    [ "Appendix", "appendix.html", "appendix" ],
    [ "Changelog", "changelog.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"classboost_1_1locale_1_1generator.html#a99fb69f05b0d3f86e37f52b8282c2f18",
"group__boundary.html#ga0f144a68688caf101e88f6824e1f0130",
"group__message.html#ga33bdf7fbb164a96a8685b5747afc2b45",
"using_localization_backends.html#supported_features_by_backends"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
